/*
 * Lachesis, an IRCRPG combat engine - Bot action command handler.
 * Copyright 2002 M. Dennis
 *
 * This program is free software; please see the file COPYING for details.
 * Note: This acts as the root command handler for RPGServ.
 */

#ifndef _CMD_ACTIONS_H_
#define _CMD_ACTIONS_H_

#ifndef RPGSERV
void Cmd_actions_Init();
void Cmd_Actions_Root(void *, int, const char *);
#endif

#endif
